@@ -26,6 +26,9 @@
 
 """
 
+from mt_exceptions import UnexpectedObjectError
+
+
 class Composition:
 
 	title = 'Untitled'
@@ -50,10 +53,15 @@ class Composition:
 		self.set_author()
 
 	def add_track(self, track):
-		"""Adds a track to the composition"""
-		# Should raise exception
+		"""Adds a track to the composition. Raises an
+		UnexpectedObjectError if the argument is not a 
+		mingus.containers.Track object."""
+
+
 		if not ( hasattr ( track, "bars" ) ):
-			return False
+			raise UnexpectedObjectError,\
+				"Unexpected object '%s', expecting a"\
+				" mingus.containers.Track object" % track
 		self.tracks.append(track)
 		self.selected_tracks = [len(self.tracks) - 1]
 
