@@ -37,6 +37,7 @@
 """
 
 from mingus.core import notes
+from mt_exceptions import NoteFormatError
 
 __all__ = ['Note']
 
@@ -50,19 +51,20 @@ class Note:
 		self.set_note(name, octave, dynamics)
 
 	def set_note(self, name = 'C', octave = 4, dynamics = {}):
-		"""Sets the note to name in octave with dynamics if
-		the name of the note is valid. Returns True if it 
-		succeeded, False otherwise."""
+		"""Sets the note to `name` in `octave` with `dynamics` if
+		the name of the note is valid. Returns the objects if it 
+		succeeded, raises an NoteFormatError otherwise."""
 		dash_index = name.split('-')
 		if len(dash_index) == 1:
 			if notes.is_valid_note(name):
 				self.name = name
 				self.octave = octave
 				self.dynamics = dynamics
-				return True
+				return self
 			else:
-				#Raise exception
-				return False
+				raise NoteFormatError,\
+					"The string '%s' is not a valid representation"\
+					"of a note in mingus" % name
 		elif len(dash_index) == 2:
 			if notes.is_valid_note(dash_index[0]):
 				self.name = dash_index[0]
@@ -70,11 +72,13 @@ class Note:
 				self.dynamics = dynamics
 				return True
 			else:
-				#Raise exception
-				return False
+				raise NoteFormatError,\
+					"The string '%s' is not a valid representation"\
+					"of a note in mingus" % name
 		return False
 
 	def empty(self):
+		"""Removes the data in the instance."""
 		self.name = ''
 		octave = 0
 		dynamics = {}
@@ -88,14 +92,18 @@ class Note:
 		self.name = notes.diminish(self.name)
 
 	def change_octave(self, diff):
+		"""Changes the octave of the note to 
+		the current octave + diff"""
 		self.octave += diff
 		if self.octave < 0:
 			self.octave = 0
 
 	def octave_up(self):
+		"""Increments the current octave with 1"""
 		self.change_octave(1)
 
 	def octave_down(self):
+		"""Decrements the current octave with 1"""
 		self.change_octave(-1)
 
 	def to_minor(self):
